@@ -39,6 +39,10 @@
 #define be64toh(x) OSSwapBigToHostInt64(x)
 #define le64toh(x) OSSwapLittleToHostInt64(x)
 
+#elif defined(__FreeBSD__)
+
+#include <sys/endian.h>
+
 #endif
 
 // Private prototypes useful for the logger
